@@ -392,3 +392,7 @@ class Reorder(Operator):
     def __init__(self):
         super().__init__()
 
+@operator_registry(operator_type='MergedEmbeddingbag')
+class MergedEmbeddingbag(Operator):
+    def __init__(self):
+        super().__init__()
