@@ -18,6 +18,7 @@
 
 import onnx
 from .base_operator import QuantOperatorBase
+from .qdq_base_operator import QDQOperatorBase
 from onnx import onnx_pb as onnx_proto
 from onnxruntime.quantization.quant_utils import QuantizedValueType, \
                                                  attribute_to_kwarg, ms_domain
@@ -30,7 +31,7 @@ class EmbedLayerNormalizationQuant(QuantOperatorBase): # pragma: no cover
     def __init__(self, onnx_quantizer, onnx_node):
         super().__init__(onnx_quantizer, onnx_node)
 
-    def quantize(self):
+    def convert(self):
         node = self.node
         assert (node.op_type == "EmbedLayerNormalization")
 
@@ -45,11 +46,23 @@ class EmbedLayerNormalizationQuant(QuantOperatorBase): # pragma: no cover
         [6] beta (float32)
         [7] mask (int32) (optional)
         '''
-        (quantized_input_names, zero_point_names, scale_names, nodes) = \
-            self.quantizer.quantize_inputs(node, [2, 3, 4, 5, 6])
-        if quantized_input_names is None:
-            return super().quantize()
 
+        parents = self.quantizer.model.get_parents(node)
+        inputs = []
+        # 'input_ids'
+        inputs.extend([node.input[0]])
+        # 'segment_ids'
+        inputs.extend([node.input[1]])
+        for parent in parents:
+            inputs.append(parent.input[0])
+        # 'mask' (optional)
+        inputs.extend([node.input[7] if len(node.input) > 7 else ""])
+
+        for parent in parents:
+            inputs.append(parent.input[1])
+        for parent in parents:
+            inputs.append(parent.input[2])
+ 
         qembed_layer_norm_name = "" if node.name == "" else node.name + "_quant"
 
         '''
@@ -73,45 +86,23 @@ class EmbedLayerNormalizationQuant(QuantOperatorBase): # pragma: no cover
         [16] gamma_zero_point (uint8)
         [17] beta_zero_point (uint8)
         '''
-        inputs = []
-        # 'input_ids'
-        inputs.extend([node.input[0]])
-        # 'segment_ids'
-        inputs.extend([node.input[1]])
-        # 'word_embedding_quant'
-        inputs.extend([quantized_input_names[0]])
-        # 'position_embedding_quant'
-        inputs.extend([quantized_input_names[1]])
-        # 'segment_embedding_quant'
-        inputs.extend([quantized_input_names[2]])
-        # 'gamma_quant'
-        inputs.extend([quantized_input_names[3]])
-        # 'beta_quant'
-        inputs.extend([quantized_input_names[4]])
-        # 'mask' (optional)
-        inputs.extend([node.input[7] if len(node.input) > 7 else ""])
-
-        # Add all scales:
-        inputs.extend([scale_names[0]])
-        inputs.extend([scale_names[1]])
-        inputs.extend([scale_names[2]])
-        inputs.extend([scale_names[3]])
-        inputs.extend([scale_names[4]])
-
-        # Add all zero points:
-        inputs.extend([zero_point_names[0]])
-        inputs.extend([zero_point_names[1]])
-        inputs.extend([zero_point_names[2]])
-        inputs.extend([zero_point_names[3]])
-        inputs.extend([zero_point_names[4]])
-
         kwargs = {}
         for attribute in node.attribute:
             kwargs.update(attribute_to_kwarg(attribute))
         kwargs["domain"] = ms_domain
 
-        qembed_layer_norm_node = onnx.helper.make_node("QEmbedLayerNormalization", inputs, node.output,
+        qembed_layer_norm_node = onnx.helper.make_node("QEmbedLayerNormalization", 
+                                                       inputs, node.output,
                                                        qembed_layer_norm_name, **kwargs)
-        nodes.append(qembed_layer_norm_node)
+        self.quantizer.new_nodes.append(qembed_layer_norm_node)
+        self.quantizer.remove_nodes.extend(parents)
 
-        self.quantizer.new_nodes += nodes
+class QDQEmbedLayerNormalization(QDQOperatorBase): # pragma: no cover
+    def __init__(self, onnx_quantizer, onnx_node):
+        super().__init__(onnx_quantizer, onnx_node)
+
+    def quantize(self):
+        node = self.node
+        assert (node.op_type == "EmbedLayerNormalization")
+
+        self.quantizer.quantize_inputs(node, [2, 3, 4, 5, 6])
