@@ -17,9 +17,10 @@
 
 import os
 import copy
-from collections import OrderedDict
 import yaml
+import math
 import numpy as np
+from collections import OrderedDict, UserDict
 from .query import QueryBackendCapability
 from .adaptor import adaptor_registry, Adaptor
 from ..utils.utility import LazyImport, CpuInfo, singleton, Dequantize, dump_elapsed_time
@@ -27,7 +28,6 @@ from ..utils.utility import Statistics, GLOBAL_STATE, MODE
 from ..utils import logger
 from ..conf.dotdict import deep_get
 from ..experimental.data.dataloaders.base_dataloader import BaseDataLoader
-import math
 tensorflow = LazyImport('tensorflow')
 
 
@@ -328,11 +328,33 @@ class TensorFlowAdaptor(Adaptor):
             for idx, (inputs, labels) in enumerate(dataloader):
                 # dataloader should keep the order and len of inputs same with input_tensor
                 if len(input_tensor) == 1:
-                    feed_dict = {input_tensor[0]: inputs}  # get raw tensor using index [0]
+                    feed_dict = {}
+                    if isinstance(inputs, dict) or isinstance(inputs, OrderedDict) \
+                      or isinstance(inputs, UserDict):
+                        for name in inputs:
+                            for tensor in input_tensor:
+                                pos = tensor.name.rfind(":")
+                                t_name = tensor.name if pos < 0 else tensor.name[:pos]
+                                if name == t_name:
+                                    feed_dict[tensor] = inputs[name]
+                                    break
+                    else:
+                        feed_dict = {input_tensor[0]: inputs}  # get raw tensor using index [0]
                 else:
                     assert len(input_tensor) == len(inputs), \
                         'inputs len must equal with input_tensor'
-                    feed_dict = dict(zip(input_tensor, inputs))
+                    feed_dict = {}
+                    if isinstance(inputs, dict) or isinstance(inputs, OrderedDict) \
+                      or isinstance(inputs, UserDict):
+                        for name in inputs:
+                            for tensor in input_tensor:
+                                pos = tensor.name.rfind(":")
+                                t_name = tensor.name if pos < 0 else tensor.name[:pos]
+                                if name == t_name:
+                                    feed_dict[tensor] = inputs[name]
+                                    break
+                    else:
+                        feed_dict = dict(zip(input_tensor, inputs))
 
                 if model.iter_op:
                     predictions = iterator_sess_run(model.sess, model.iter_op, \
@@ -1178,8 +1200,18 @@ class TensorflowQuery(QueryBackendCapability):
         Returns:
             [dictionary]: the content for specific version.
         """
+        from functools import cmp_to_key
+        from pkg_resources import parse_version
         config = None
 
+        def _compare(version1, version2):
+            if parse_version(version1) == parse_version(version2):
+                return 0
+            elif parse_version(version1) < parse_version(version2):
+                return -1
+            else:
+                return 1 
+
         fallback_list = []
         for sub_data in data:
             if 'default' in sub_data['version']['name']:
@@ -1191,20 +1223,24 @@ class TensorflowQuery(QueryBackendCapability):
                 return sub_data
             else:
                 sorted_list = copy.deepcopy(sub_data['version']['name'])
-                if isinstance(sorted_list, list):
-                    sorted_list.sort()
-                else:
-                    sorted_list = list(sorted_list)
                 sorted_list.remove('default') if 'default' in sorted_list else None
-                import bisect
-                position = bisect.bisect(sorted_list, self.version)
-                if position != 0:
-                    fallback_list.append([sorted_list[position - 1], sub_data])
+                if isinstance(sorted_list, list):
+                    # TensorFlow 1.15.0-up1/up2/up3 release versions are abnoraml release naming
+                    # convention. Replacing them with dot for version comparision. 
+                    sorted_list = [i.replace('-up', '.') for i in sorted_list]
+                    sorted_list = sorted(sorted_list, key=cmp_to_key(_compare), reverse=True)
+                else:
+                    assert isinstance(sorted_list, str)
+                    sorted_list = list(sorted_list.replace('-up', '.').split())
+                for i in sorted_list:
+                    if parse_version(self.version) >= parse_version(i):
+                        fallback_list.append([i, sub_data])
+                        break
 
         assert config != None, "The default config in framework yaml must exist."
         nearest_version = str(0)
         for fallback in fallback_list:
-            if fallback[0] > nearest_version:
+            if parse_version(fallback[0]) > parse_version(nearest_version):
                 nearest_version = fallback[0]
                 config = fallback[1]
 
