@@ -21,6 +21,8 @@ import os
 import logging
 import tempfile
 import tensorflow as tf
+
+from collections import OrderedDict, UserDict
 from tensorflow.core.framework import graph_pb2
 from tensorflow.python.framework import tensor_util
 from tensorflow.python.platform import gfile
@@ -61,7 +63,7 @@ from neural_compressor.adaptor.tf_utils.graph_rewriter.generic.insert_print_node
 from neural_compressor.adaptor.tf_utils.graph_rewriter.graph_util import GraphRewriterHelper as Helper
 
 
-TF_SUPPORTED_MAX_VERSION = '2.8.0'
+TF_SUPPORTED_MAX_VERSION = '2.9.1'
 TF_SUPPORTED_MIN_VERSION = '1.14.0'
 
 logger = logging.getLogger()
@@ -149,11 +151,33 @@ class GraphConverter:
         logger.info("Start sampling on calibration dataset.")
         for idx, (inputs, labels) in enumerate(self.data_loader):
             if len(input_tensor) == 1:
-                feed_dict = {input_tensor[0]: inputs}  # get raw tensor using index [0]
+                feed_dict = {}
+                if isinstance(inputs, dict) or isinstance(inputs, OrderedDict) \
+                  or isinstance(inputs, UserDict):
+                    for name in inputs:
+                        for tensor in input_tensor:
+                            pos = tensor.name.rfind(":")
+                            t_name = tensor.name if pos < 0 else tensor.name[:pos]
+                            if name == t_name:
+                                feed_dict[tensor] = inputs[name]
+                                break
+                else:
+                    feed_dict = {input_tensor[0]: inputs}  # get raw tensor using index [0]
             else:
                 assert len(input_tensor) == len(inputs), \
                     'inputs len must equal with input_tensor'
-                feed_dict = dict(zip(input_tensor, inputs))
+                feed_dict = {}
+                if isinstance(inputs, dict) or isinstance(inputs, OrderedDict) \
+                  or isinstance(inputs, UserDict):
+                    for name in inputs:
+                        for tensor in input_tensor:
+                            pos = tensor.name.rfind(":")
+                            t_name = tensor.name if pos < 0 else tensor.name[:pos]
+                            if name == t_name:
+                                feed_dict[tensor] = inputs[name]
+                                break
+                else:
+                    feed_dict = dict(zip(input_tensor, inputs))
             _ = model.sess.run(output_tensor, feed_dict) if model.iter_op==[] \
                 else iterator_sess_run(model.sess, model.iter_op, \
                     feed_dict, output_tensor, self.calib_iteration)
@@ -177,6 +201,9 @@ class GraphConverter:
             if tf.version.VERSION >= '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') == '1':
                 is_supported_version = True
 
+            if tf.version.VERSION >= '2.9.0':
+                is_supported_version = True
+
         except Exception as e:
             raise ValueError(e)
         finally:
@@ -190,11 +217,12 @@ class GraphConverter:
                                                                      TF_SUPPORTED_MAX_VERSION))
             if tf.version.VERSION == '2.5.0' and os.getenv('TF_ENABLE_MKL_NATIVE_FORMAT') != '0':
                 logger.fatal("Please set environment variable TF_ENABLE_MKL_NATIVE_FORMAT=0 "
-                             "when Tensorflow 2.5.0 installed.")
+                             "when TensorFlow 2.5.0 installed.")
 
-            if tf.version.VERSION >= '2.6.0' and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
+            if tf.version.VERSION >= '2.6.0' and tf.version.VERSION < '2.9.0' \
+                    and os.getenv('TF_ENABLE_ONEDNN_OPTS') != '1':
                 logger.fatal("Please set environment variable TF_ENABLE_ONEDNN_OPTS=1 "
-                             "when Tensorflow 2.6.x installed.")
+                             "when TensorFlow >= 2.6.0 and < 2.9.0 installed.")
 
             if not is_supported_version:
                 raise ValueError(
@@ -547,7 +575,7 @@ class GraphConverter:
 
                 if self.itex_mode:
                     self._itex_model.graph_def = GenerateITEXModel(
-                        self._itex_model, self._calibration_data).do_transformation()
+                        self._itex_model, self._calibration_data, self.device).do_transformation()
                     self._itex_model.graph_def.library.CopyFrom(
                         self.model.graph_def.library)
 
