@@ -205,7 +205,7 @@ ops_schema = Schema({
             lambda s: all(i in ['asym', 'sym', 'asym_float'] for i in s)),
         Optional('dtype', default=None): And(
             list,
-            lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+            lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'fp16'] for i in s)),
         Optional('algorithm', default=None): And(
             list,
             lambda s: all(i in ['minmax'] for i in s)),
@@ -223,7 +223,7 @@ ops_schema = Schema({
             lambda s: all(i in ['asym', 'sym'] for i in s)),
         Optional('dtype', default=None): And(
             list,
-            lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+            lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'fp16'] for i in s)),
         # compute_dtypeis only for PyTorch framework
         Optional('compute_dtype', default=['uint8']): And(
             list,
@@ -247,7 +247,7 @@ graph_optimization_schema = Schema({
             Optional('dtype', default=None): And(
                 Or(str, list),
                 Use(input_to_list),
-                lambda s: all(i in ['fp32', 'bf16'] for i in s)),
+                lambda s: all(i in ['fp32', 'bf16', 'fp16'] for i in s)),
         },
         Optional('activation', default=None): {
             Optional('dtype', default=None): And(
@@ -399,7 +399,8 @@ postprocess_schema = Schema({
     Optional('SquadV1'): {
         'label_file': str,
         'vocab_file': str,
-        Optional('do_lower_case', default='True'): bool
+        Optional('do_lower_case', default='True'): bool,
+        Optional('max_seq_length', default=384): int,
     },
 })
 
@@ -713,7 +714,7 @@ schema = Schema({
                 Optional('dtype', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
-                    lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+                    lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'fp16'] for i in s)),
                 Optional('algorithm', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
@@ -736,7 +737,7 @@ schema = Schema({
                 Optional('dtype', default=None): And(
                     Or(str, list),
                     Use(input_to_list),
-                    lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16'] for i in s)),
+                    lambda s: all(i in ['int8', 'uint8', 'fp32', 'bf16', 'fp16'] for i in s)),
                 # compute_dtypeis only for PyTorch framework
                 Optional('compute_dtype', default=['uint8']): And(
                     Or(str, list),
@@ -1455,3 +1456,9 @@ class DefaultConf(DotDict):
     __getattr__ = __getitem__
 
 conf = DefaultConf({})
+
+QuantConf = Quantization_Conf
+PruningConf = Pruning_Conf
+GraphOptConf = Graph_Optimization_Conf
+BenchmarkConf = Benchmark_Conf
+DistillationConf = Distillation_Conf
