@@ -23,7 +23,7 @@ import signal
 import psutil
 from ..adaptor import FRAMEWORKS
 from ..objective import MultiObjective
-from ..conf.config import Benchmark_Conf
+from ..conf.config import BenchmarkConf
 from ..conf.dotdict import DotDict
 from ..utils import logger
 from ..utils import OPTIONS
@@ -63,9 +63,6 @@ def set_all_env_var(conf, overwrite_existing=False):
     
     for var, value in conf.items():
         set_env_var(var.upper(), value, overwrite_existing)
-    # a special but usually used case, directly use current process
-    if conf['num_of_instance'] == 1 and conf['cores_per_instance'] == cpu_counts:
-        set_env_var('NC_ENV_CONF', True, overwrite_existing=True)
 
 class Benchmark(object):
     """Benchmark class can be used to evaluate the model performance, with the objective
@@ -75,7 +72,7 @@ class Benchmark(object):
 
     Args:
         conf_fname_or_obj (string or obj): The path to the YAML configuration file or
-            Benchmark_Conf class containing accuracy goal, tuning objective and preferred
+            BenchmarkConf class containing accuracy goal, tuning objective and preferred
             calibration & quantization tuning space etc.
 
     """
@@ -86,10 +83,10 @@ class Benchmark(object):
         self._b_dataloader = None
         self._metric = None
         self._results = {}
-        if isinstance(conf_fname_or_obj, Benchmark_Conf):
+        if isinstance(conf_fname_or_obj, BenchmarkConf):
             self.conf = conf_fname_or_obj
         else:
-            self.conf = Benchmark_Conf(conf_fname_or_obj)
+            self.conf = BenchmarkConf(conf_fname_or_obj)
         if self.conf.usr_cfg.model.framework != 'NA':
             self.framework = self.conf.usr_cfg.model.framework.lower()
             set_backend(self.framework)
@@ -102,6 +99,9 @@ class Benchmark(object):
             mode = list(cfg.evaluation.keys())[0]
         assert sys.platform in ['linux', 'win32'], 'only support platform windows and linux...'
         set_all_env_var(deep_get(cfg, 'evaluation.{}.configs'.format(mode)))
+        # disable multi-instance for accuracy mode
+        if mode == "accuracy":
+            set_env_var('NC_ENV_CONF', True, overwrite_existing=True)
 
         logger.info("Start to run Benchmark.")
         if os.environ.get('NC_ENV_CONF') == 'True':
