@@ -26,8 +26,7 @@ torch = LazyImport('torch')
 
 @dataset_registry(dataset_type="dummy_v2", framework="tensorflow, tensorflow_itex, engine,\
                                                       onnxrt_qlinearops, onnxrt_integerops, \
-                                                      pytorch, pytorch_ipex, pytorch_fx, \
-                                                      mxnet, onnxrt_qdqops",
+                                                      pytorch, pytorch_ipex, pytorch_fx, mxnet",
                                                       dataset_format='')
 class DummyDataset(IterableDataset):
     """Dataset used for dummy_v2 data generation.
@@ -146,8 +145,7 @@ class DummyDataset(IterableDataset):
 
 @dataset_registry(dataset_type="sparse_dummy_v2", framework="tensorflow, tensorflow_itex, engine,\
                                                       onnxrt_qlinearops, onnxrt_integerops, \
-                                                      pytorch, pytorch_ipex, pytorch_fx, \
-                                                      mxnet, onnxrt_qdqops",
+                                                      pytorch, pytorch_ipex, pytorch_fx, mxnet",
                                                       dataset_format='')
 class SparseDummyDataset(IterableDataset):
     """Dataset used for sparse_dummy_v2 data generation.
