@@ -30,12 +30,6 @@ class ONNXRTQLFilters(object):
         self.filters = {}
         self.filters.update(ONNXRT_QL_FILTERS)
 
-@singleton
-class ONNXRTQDQFilters(object):
-    def __init__(self):
-        self.filters = {}
-        self.filters.update(ONNXRT_QDQ_FILTERS)
-
 @singleton
 class ONNXRTITFilters(object):
     def __init__(self):
@@ -57,7 +51,6 @@ class MXNetFilters(object):
 TENSORFLOW_FILTERS = {}
 ONNXRT_IT_FILTERS = {}
 ONNXRT_QL_FILTERS = {}
-ONNXRT_QDQ_FILTERS = {}
 PYTORCH_FILTERS = {}
 MXNET_FILTERS = {}
 
@@ -68,7 +61,8 @@ framework_filters = {"tensorflow": TensorflowFilters,
                      "pytorch_fx": PyTorchFilters,
                      "mxnet": MXNetFilters,
                      "onnxrt_qlinearops": ONNXRTQLFilters,
-                     "onnxrt_qdqops": ONNXRTQDQFilters,
+                     "onnxrt_qdq": ONNXRTQLFilters,
+                     "onnxrt_qoperator": ONNXRTQLFilters,
                      "onnxrt_integerops": ONNXRTITFilters,
                      }
 
@@ -79,14 +73,15 @@ registry_filters = {"tensorflow": TENSORFLOW_FILTERS,
                     "pytorch_fx": PYTORCH_FILTERS,
                     "mxnet": MXNET_FILTERS,
                     "onnxrt_integerops": ONNXRT_IT_FILTERS,
-                    "onnxrt_qdqops": ONNXRT_QDQ_FILTERS,
+                    "onnxrt_qdq": ONNXRT_QL_FILTERS,
+                    "onnxrt_qoperator": ONNXRT_QL_FILTERS,
                     "onnxrt_qlinearops": ONNXRT_QL_FILTERS}
 
 class FILTERS(object):
     def __init__(self, framework):
-        assert framework in ["tensorflow", "tensorflow_itex", "onnxrt_qdqops",
+        assert framework in ["tensorflow", "tensorflow_itex", "onnxrt_qdq",
                             "pytorch", "pytorch_ipex", "pytorch_fx", "mxnet",
-                             "onnxrt_integerops", "onnxrt_qlinearops"], \
+                             "onnxrt_integerops", "onnxrt_qlinearops", "onnxrt_qoperator"], \
                              "framework support tensorflow pytorch mxnet onnxrt"
         self.filters = framework_filters[framework]().filters
         self.framework = framework
@@ -119,8 +114,9 @@ def filter_registry(filter_type, framework):
                 "pytorch_fx",
                 "mxnet",
                 "onnxrt_integerops",
-                "onnxrt_qdqops",
-                "onnxrt_qlinearops"
+                "onnxrt_qdq",
+                "onnxrt_qlinearops",
+                "onnxrt_qoperator"
             ], "The framework support tensorflow mxnet pytorch onnxrt"
             if filter_type in registry_filters[single_framework].keys():
                 raise ValueError('Cannot have two transforms with the same name')
