@@ -233,7 +233,8 @@ class TuneStrategy(object):
         else:
             self.calib_iter = [1]
 
-        fallback_precision_list = ['fp32'] if self.graph_optimization_mode else ['fp32', 'bf16']
+        fallback_precision_list = ['fp32'] if self.graph_optimization_mode \
+            else ['fp32', 'bf16', 'fp16']
         self.model_wise_quant_cfgs = OrderedDict()
         for optype in self.model_wise_tune_cfgs.keys():
             self.model_wise_quant_cfgs[optype] = []
@@ -501,7 +502,9 @@ class TuneStrategy(object):
                 # Pytorch can insert observer to model in this hook.
                 # Tensorflow don't support this mode for now
                 model = self.adaptor._pre_eval_hook(model)
-            val = self.objectives.evaluate(self.eval_func, model.model)
+            val = self.objectives.evaluate(
+                self.eval_func, model if self.framework == "pytorch_ipex" else model.model
+            )
             if self.cfg.tuning.tensorboard:
                 # post_eval_hook to deal the tensor
                 self.adaptor._post_eval_hook(model, accuracy=val[0])
