@@ -31,7 +31,8 @@ OPTIONS = {'tensorflow': None,
            'mxnet': None,
            'onnxrt_integerops': onnxrt,
            'onnxrt_qlinearops': onnxrt,
-           'onnxrt_qdqops': onnxrt,
+           'onnxrt_qdq': onnxrt,
+           'onnxrt_qoperator': onnxrt,
            'engine': None}
 
 
