@@ -25,3 +25,8 @@ class FrozenPbModel(TFModel):
     def supports_path(path: str) -> bool:
         """Check if given path is of supported model."""
         return "frozen_pb" == get_model_type(path)
+
+    @property
+    def supports_profiling(self) -> bool:
+        """Check if profiling is supported for the model."""
+        return True
