@@ -19,9 +19,11 @@ from time import sleep
 from typing import List, Optional
 
 from neural_compressor.utils.utility import get_tuning_history
+from neural_compressor.ux.components.db_manager.db_operations import OptimizationAPIInterface
 from neural_compressor.ux.components.optimization.optimization import Optimization
-from neural_compressor.ux.utils.exceptions import NotFoundException
-from neural_compressor.ux.utils.workload.config import Config
+from neural_compressor.ux.components.optimization.tune.tuning import AccuracyCriterion, Tuning
+from neural_compressor.ux.utils.exceptions import InternalException, NotFoundException
+from neural_compressor.ux.utils.logger import log
 from neural_compressor.ux.web.communication import MessageQueue
 from neural_compressor.ux.web.service.history_snapshot_parser import HistorySnapshotParser
 
@@ -29,13 +31,14 @@ mq = MessageQueue()
 
 
 def tuning_history(optimization: Optimization) -> dict:
-    """Get tuning history for requested Optimization."""
+    """Get tuning history for requested Tuning."""
     response = {
         "optimization_id": optimization.id,
     }
     history_path = tuning_history_path(optimization.workdir)
 
     tuning_data = _build_tuning_history(optimization, history_path)
+
     response.update(tuning_data)
 
     return response
@@ -47,14 +50,9 @@ def _build_tuning_history(optimization: Optimization, history_path: str) -> dict
         raise NotFoundException(f"Unable to find tuning history file {history_path}")
     history_snapshot = get_tuning_history(history_path)
 
-    config_path = optimization.config_path
-    if not config_path:
-        raise NotFoundException("Unable to find config file")
-    config = Config()
-    config.load(config_path)
     objective: List[str] = ["performance"]
-    if config.tuning.multi_objective:
-        objective = config.tuning.multi_objective.objective
+    if isinstance(optimization, Tuning) and optimization.tuning_details.objective:
+        objective = [optimization.tuning_details.objective]
 
     history_snapshot_parser = HistorySnapshotParser(
         history_snapshot,
@@ -62,28 +60,33 @@ def _build_tuning_history(optimization: Optimization, history_path: str) -> dict
     )
     tuning_data = history_snapshot_parser.parse_history_snapshot()
 
-    if not tuning_data.get("baseline_accuracy"):
-        raise NotFoundException("Can't find baseline accuracy")
-
-    baseline_accuracy = tuning_data.get("baseline_accuracy", 0)
-    accuracy_criterion = config.tuning.accuracy_criterion
-    if accuracy_criterion.relative:
-        accuracy_criterion_type = "relative"
-        accuracy_criterion_value = accuracy_criterion.relative
-        minimal_accuracy = baseline_accuracy * (1 - accuracy_criterion_value)
-    elif accuracy_criterion.absolute:
-        accuracy_criterion_type = "absolute"
-        accuracy_criterion_value = accuracy_criterion.absolute
-        minimal_accuracy = baseline_accuracy - accuracy_criterion_value
-    else:
-        raise NotFoundException("Unknown accuracy type")
+    baseline_accuracy: float = 0.0
+    minimal_accuracy: float = 0.0
+    accuracy_criterion: AccuracyCriterion = AccuracyCriterion()
+    accuracy_criterion.type = "relative"
+    accuracy_criterion.threshold = 0.1
+    if isinstance(optimization, Tuning):
+        if tuning_data.baseline_accuracy is not None:
+            baseline_accuracy = tuning_data.baseline_accuracy[0]
+        accuracy_criterion = optimization.tuning_details.accuracy_criterion
+        if accuracy_criterion.type == "relative":
+            minimal_accuracy = baseline_accuracy * (1 - accuracy_criterion.threshold)
+        elif accuracy_criterion.type == "absolute":
+            minimal_accuracy = baseline_accuracy - accuracy_criterion.threshold
+        else:
+            raise NotFoundException("Unknown accuracy type")
 
     response = {
-        "accuracy_criterion_type": accuracy_criterion_type,
-        "accuracy_criterion_value": accuracy_criterion_value,
-        "minimal_accuracy": minimal_accuracy,
+        "accuracy_criterion_type": accuracy_criterion.type,
+        "accuracy_criterion_value": accuracy_criterion.threshold,
     }
-    response.update(tuning_data)
+    tuning_data.minimal_accuracy = minimal_accuracy
+
+    serialized_tuning_data = tuning_data.serialize()
+
+    if not isinstance(serialized_tuning_data, dict):
+        raise InternalException("Incorrect type of tuning data.")
+    response.update(serialized_tuning_data)
     return response
 
 
@@ -95,23 +98,32 @@ def tuning_history_path(optimization_workdir: str) -> str:
 class Watcher:
     """Tuning history watcher that sends update on file change."""
 
-    def __init__(self, optimization: Optimization) -> None:
+    def __init__(self, request_id: str, optimization: Optimization) -> None:
         """Initialize object."""
         self.optimization = optimization
+        self.request_id = request_id
         self.watch = False
         self.tuning_history_path = tuning_history_path(optimization.workdir)
         self.last_tuning_history_timestamp = self.history_file_modification_time()
 
-    def stop(self) -> None:
-        """Signal watcher to stop."""
+    def stop(self, process_succeeded: bool) -> None:
+        """Signal watcher to stop and dump tuning history to database."""
         self.watch = False
+        if not process_succeeded:
+            log.debug("Tuning process failed. Skipping collecting tuning history.")
+            return
+        history = tuning_history(self.optimization)
+        OptimizationAPIInterface.add_tuning_history(
+            optimization_id=self.optimization.id,
+            tuning_history=history,
+        )
 
     def __call__(self) -> None:
         """Execute the watch."""
         self.watch = True
         while self.watch:
             if self.was_history_file_changed():
-                TuningHistory.send_history_snapshot(self.optimization)
+                TuningHistory.send_history_snapshot(self.request_id, self.optimization)
             sleep(10)
 
     def was_history_file_changed(self) -> bool:
@@ -134,10 +146,11 @@ class TuningHistory:
     """Tuning history class."""
 
     @staticmethod
-    def send_history_snapshot(optimization: Optimization) -> None:
+    def send_history_snapshot(request_id: str, optimization: Optimization) -> None:
         """Get tuning history for requested Workload."""
         try:
             response = tuning_history(optimization)
+            response.update({"request_id": request_id})
             mq.post_success("tuning_history", response)
         except NotFoundException:
             mq.post_error(
