@@ -16,7 +16,6 @@ from neural_compressor.experimental import Benchmark, common
 from neural_compressor import options
 from neural_compressor.adaptor.pytorch import get_torch_version, PyTorchVersionMode
 from neural_compressor import conf
-from onnxruntime_extensions import onnx_op
 
 def build_static_yaml():
     fake_yaml = """
@@ -38,7 +37,8 @@ def build_static_yaml():
         evaluation:
           accuracy:
             metric:
-              topk: 1
+              MSE:
+                compare_label: False
 
         tuning:
           accuracy_criterion:
@@ -55,7 +55,7 @@ def build_static_yaml():
     fake_yaml = """
         model:
           name: imagenet
-          framework: onnxrt_qdqops
+          framework: onnxrt_qdq
 
         quantization:                                        
           approach: post_training_static_quant  
@@ -71,7 +71,8 @@ def build_static_yaml():
         evaluation:
           accuracy:
             metric:
-              topk: 1
+              MSE:
+                compare_label: False
 
         tuning:
           accuracy_criterion:
@@ -130,7 +131,8 @@ def build_dynamic_yaml():
         evaluation:
           accuracy:
             metric:
-              topk: 1
+              MSE:
+                compare_label: False
 
         tuning:
           accuracy_criterion:
@@ -339,26 +341,48 @@ def build_rename_model():
     model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
     return model
 
+def build_benchmark():
+    seq = '''
+from neural_compressor.experimental import Benchmark
+from neural_compressor.data import DATASETS, DATALOADERS
+from neural_compressor import conf
+from onnx import onnx_pb as onnx_proto
+from onnx import helper, TensorProto, numpy_helper
+from onnxruntime_extensions import onnx_op
+import numpy as np
+
 @onnx_op(op_type="PyReverseMatrix")
 def reverse_matrix(x):
     # The user custom op implementation here.
     return np.flip(x, axis=0).astype(np.float32)
 
-def build_ext_model():
-    nodes = []
-    nodes[0:] = [helper.make_node('Identity', ['input_1'], ['identity1'])]
-    nodes[1:] = [helper.make_node('PyReverseMatrix',
-                                  ['identity1'], ['reversed'],
-                                  domain='ai.onnx.contrib')]
+nodes = []
+nodes[0:] = [helper.make_node('Identity', ['input_1'], ['identity1'])]
+nodes[1:] = [helper.make_node('PyReverseMatrix',
+                              ['identity1'], ['reversed'],
+                              domain='ai.onnx.contrib')]
 
-    input0 = helper.make_tensor_value_info(
-            'input_1', onnx_proto.TensorProto.FLOAT, [None, 2])
-    output0 = helper.make_tensor_value_info(
-            'reversed', onnx_proto.TensorProto.FLOAT, [None, 2])
+input0 = helper.make_tensor_value_info(
+        'input_1', onnx_proto.TensorProto.FLOAT, [None, 2])
+output0 = helper.make_tensor_value_info(
+        'reversed', onnx_proto.TensorProto.FLOAT, [None, 2])
 
-    graph = helper.make_graph(nodes, 'test0', [input0], [output0])
-    model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
-    return model
+graph = helper.make_graph(nodes, 'test0', [input0], [output0])
+model = helper.make_model(graph, **{'opset_imports': [helper.make_opsetid('', 13)]})
+
+datasets = DATASETS('onnxrt_qlinearops')
+ext_dataset = datasets['dummy'](shape=(10, 2), low=0., high=1., label=True)
+ext_dataloader = DATALOADERS['onnxrt_qlinearops'](ext_dataset)
+
+conf.model.framework = 'onnxrt_qlinearops'
+conf.evaluation.accuracy.metric = {'Accuracy': {}}
+evaluator = Benchmark(conf)
+evaluator.b_dataloader = ext_dataloader
+evaluator.model = model
+evaluator('performance')
+    '''
+    with open('benchmark.py', "w", encoding="utf-8") as f:
+        f.writelines(seq)
 
 class MatmulDataset:
     def __init__(self):
@@ -417,7 +441,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
         self.gather_model = build_model_with_gather()
         self.matmul_model = build_matmul_model()
         self.rename_model = build_rename_model()
-        self.ext_model = build_ext_model()
+        build_benchmark()
 
     @classmethod
     def tearDownClass(self):
@@ -437,13 +461,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
         shutil.rmtree("./nc_workspace", ignore_errors=True)
 
     def test_ext_model(self):
-        from neural_compressor.experimental import Benchmark
-        conf.model.framework = 'onnxrt_qlinearops'
-        conf.evaluation.accuracy.metric = {'Accuracy': {}}
-        evaluator = Benchmark(conf)
-        evaluator.b_dataloader = self.ext_dataloader
-        evaluator.model = self.ext_model
-        evaluator('performance')
+        os.system("python benchmark.py" )
 
     def test_adaptor_register(self):
         from neural_compressor.adaptor.adaptor import adaptor_registry
@@ -498,7 +516,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
                                              'imagenet')}
         framework = "onnxrt_qlinearops"
         adaptor = FRAMEWORKS[framework](framework_specific_info) 
-        q_config = {'fused ' + self.mb_v2_model.graph.node[0].name: {'weight': {'granularity': 'per_channel', 'dtype': onnx_proto.TensorProto.INT8, 'scheme': 'sym'}}}
+        q_config = {self.mb_v2_model.graph.node[0].name: {'weight': {'granularity': 'per_channel', 'dtype': onnx_proto.TensorProto.INT8, 'scheme': 'sym'}}}
         adaptor.quantize_config = q_config
         version = get_torch_version()
         q_model.save('./best_model.onnx')
@@ -570,6 +588,29 @@ class TestAdaptorONNXRT(unittest.TestCase):
         adaptor.quantize(tune_cfg, common.Model(self.gather_model), self.gather_dataloader)
         self.assertTrue(len(adaptor.quantizable_ops), 2)
  
+        framework_specific_info['device'] = 'gpu'
+        adaptor = FRAMEWORKS[framework](framework_specific_info) 
+        tune_cfg = {'calib_iteration': 1,
+                    'op': {('gather', 'Gather'): {'activation':  {'dtype': 'fp16'},
+                                                 'weight': {'dtype': 'fp16'}},
+                           ('add', 'Add'): {'activation':  {'dtype': 'fp16'},
+                                           'weight': {'dtype': 'fp16'}},
+                           ('squeeze', 'Squeeze'): {'activation':  {'dtype': 'fp16'},
+                                                   'weight': {'dtype': 'fp16'}}}}
+        model = adaptor.quantize(tune_cfg, common.Model(self.gather_model), self.gather_dataloader)
+        self.assertTrue(len([i for i in model.model.graph.node if i.op_type == 'Cast']), 2)
+
+        tune_cfg = {'calib_iteration': 1,
+                    'op': {('Matmul', 'MatMul'): {'activation':  {'dtype': ['uint8']},
+                                                 'weight': {'dtype': ['int8']}},
+                           ('add', 'Add'): {'activation':  {'dtype': 'fp16'},
+                                           'weight': {'dtype': 'fp16'}},
+                           ('add2', 'Add'): {'activation':  {'dtype': 'fp16'},
+                                                   'weight': {'dtype': 'fp16'}}}}
+        adaptor = FRAMEWORKS[framework](framework_specific_info) 
+        model = adaptor.quantize(tune_cfg, common.Model(self.matmul_model), self.matmul_dataloader)
+        self.assertTrue(len([i for i in model.model.graph.node if i.op_type == 'Cast']), 2)
+ 
         for fake_yaml in ["gather.yaml"]:
             quantizer = Quantization(fake_yaml)
             quantizer.model = self.gather_model
@@ -622,7 +663,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
             q_model = quantizer.fit()
             self.assertNotEqual(q_model, None)
 
-        for mode in ["performance", "accuracy"]:
+        for mode in ["accuracy"]:
             fake_yaml = "benchmark.yaml"
             evaluator = Benchmark(fake_yaml)
             evaluator.b_dataloader = self.cv_dataloader
@@ -633,6 +674,7 @@ class TestAdaptorONNXRT(unittest.TestCase):
         import time
         conf.model.framework = 'onnxrt_qlinearops'
         conf.quantization.approach = 'post_training_static_quant'
+        conf.quantization.model_wise = {'weight': {'granularity': ['per_tensor']}, 'activation': {'granularity': ['per_tensor']}}
         conf.tuning.exit_policy.max_trials = 6
         conf.tuning.accuracy_criterion.relative = 0.01
         conf.tuning.accuracy_criterion.higher_is_better = False
