@@ -10,13 +10,12 @@ from neural_compressor.model import MODELS
 from neural_compressor.adaptor.pytorch import PyTorchVersionMode
 import neural_compressor.adaptor.pytorch as nc_torch
 from neural_compressor.experimental import Quantization, common
-from neural_compressor.conf.config import Quantization_Conf
+from neural_compressor.conf.config import QuantConf
 from neural_compressor.utils.pytorch import load
 from neural_compressor.utils.utility import recover
 import shutil
 import copy
 import numpy as np
-import yaml
 
 try:
     try:
@@ -147,6 +146,10 @@ fake_ptq_yaml_for_fx = '''
                 'activation': {'dtype': ['fp32']},
                 'weight': {'dtype': ['fp32']}
               },
+              'conv.module': {
+                'weight': {'dtype': ['fp32']},
+                'activation': {'dtype': ['fp32']}
+              },
               'default_qconfig': {
                 'activation':  {'dtype': ['fp32']},
                 'weight': {'dtype': ['fp32']}
@@ -420,6 +423,38 @@ class DynamicControlModel(torch.nn.Module):
         return x
 
 
+class LSTMModel(nn.Module):
+    '''Container module with an encoder, a recurrent module, and a decoder.'''
+
+    def __init__(self, ntoken=10, ninp=512, nhid=256, nlayers=5, dropout=0.5):
+        super(LSTMModel, self).__init__()
+        self.drop = nn.Dropout(dropout)
+        self.encoder = nn.Embedding(ntoken, ninp)
+        self.rnn = nn.LSTM(ninp, nhid, nlayers, dropout=dropout)
+        self.decoder = nn.Linear(nhid, ntoken)
+        self.init_weights()
+        self.nhid = nhid
+        self.nlayers = nlayers
+
+    def init_weights(self):
+        initrange = 0.1
+        self.encoder.weight.data.uniform_(-initrange, initrange)
+        self.decoder.bias.data.zero_()
+        self.decoder.weight.data.uniform_(-initrange, initrange)
+
+    def forward(self, input):
+        input = torch.ones((3, 10), dtype=torch.int32)
+        h0 = torch.randn(2, 10, 256)
+        c0 = torch.randn(2, 10, 256)
+        hidden = (h0, c0)
+        emb = self.encoder(input)
+        #import pdb;pdb.set_trace()
+        output, hidden = self.rnn(emb, hidden)
+        output = self.drop(output)
+        decoded = self.decoder(output)
+        return decoded, hidden
+
+
 def eval_func(model):
     # switch to evaluate mode
     model.eval()
@@ -544,15 +579,13 @@ class TestPytorchAdaptor(unittest.TestCase):
         # Load configure and weights by neural_compressor.model
         evaluator.model = model
         evaluator.b_dataloader = common.DataLoader(dataset)
-        evaluator()
-        evaluator.model = model
-        evaluator()
+        evaluator.fit('accuracy')
 
         for fake_yaml in ['qat_yaml.yaml', 'ptq_yaml.yaml']:
             model = copy.deepcopy(self.model)
             if fake_yaml == 'ptq_yaml.yaml':
                 model.eval().fuse_model()
-            conf = Quantization_Conf(fake_yaml)
+            conf = QuantConf(fake_yaml)
             quantizer = Quantization(conf)
             dataset = quantizer.dataset('dummy', (100, 3, 224, 224))
             quantizer.model = model
@@ -592,7 +625,7 @@ class TestPytorchAdaptor(unittest.TestCase):
     def test_non_quant_module(self):
         for fake_yaml in ['qat_yaml.yaml', 'ptq_yaml.yaml']:
             model = PartialQuantModel()
-            conf = Quantization_Conf(fake_yaml)
+            conf = QuantConf(fake_yaml)
             quantizer = Quantization(conf)
             dataset = quantizer.dataset('dummy', (1, 3, 224, 224))
             non_quant_dict = {'non_quant_module_name': ['conv', 'conv1', 'sub.conv'], \
@@ -702,7 +735,6 @@ class TestPytorchAdaptor(unittest.TestCase):
         data = [[{'input': torch.rand(3,224,224)}, torch.ones(1,1)], ]
         # dataloader.batch_size=100
         dataloader = common.DataLoader(data, batch_size=1)
-
         quantizer = Quantization('dynamic_yaml.yaml')
         model = dummymodel(vision_model)
         quantizer.model = model
@@ -792,11 +824,18 @@ class TestPytorchIPEXAdaptor(unittest.TestCase):
         evaluator = Benchmark('ipex_yaml.yaml')
         evaluator.model = script_model
         evaluator.b_dataloader = common.DataLoader(dataset)
-        results = evaluator()
+        evaluator.fit('accuracy')
 
 
 @unittest.skipIf(not FX_MODE, "Unsupport Fx Mode with PyTorch Version Below 1.8")
 class TestPytorchFXAdaptor(unittest.TestCase):
+    framework_specific_info = {"device": "cpu",
+                               "approach": "post_training_static_quant",
+                               "random_seed": 1234,
+                               "q_dataloader": None,
+                               "workspace_path": "./"}
+    framework = "pytorch_fx"
+    adaptor = FRAMEWORKS[framework](framework_specific_info)
     @classmethod
     def setUpClass(self):
         build_pytorch_fx_yaml()
@@ -876,40 +915,12 @@ class TestPytorchFXAdaptor(unittest.TestCase):
     @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT19.value,
       "Please use PyTroch 1.9 or higher version for dynamic quantization with pytorch_fx backend")
     def test_fx_dynamic_quant(self):
-        # Model Definition
-        class LSTMModel(nn.Module):
-            '''Container module with an encoder, a recurrent module, and a decoder.'''
-
-            def __init__(self, ntoken, ninp, nhid, nlayers, dropout=0.5):
-                super(LSTMModel, self).__init__()
-                self.drop = nn.Dropout(dropout)
-                self.encoder = nn.Embedding(ntoken, ninp)
-                self.rnn = nn.LSTM(ninp, nhid, nlayers, dropout=dropout)
-                self.decoder = nn.Linear(nhid, ntoken)
-                self.init_weights()
-                self.nhid = nhid
-                self.nlayers = nlayers
-
-            def init_weights(self):
-                initrange = 0.1
-                self.encoder.weight.data.uniform_(-initrange, initrange)
-                self.decoder.bias.data.zero_()
-                self.decoder.weight.data.uniform_(-initrange, initrange)
-
-            def forward(self, input, hidden):
-                emb = self.drop(self.encoder(input))
-                output, hidden = self.rnn(emb, hidden)
-                output = self.drop(output)
-                decoded = self.decoder(output)
-                return decoded, hidden
-
         model = LSTMModel(
             ntoken = 10,
             ninp = 512,
             nhid = 256,
             nlayers = 5,
         )
-
         # run fx_quant in neural_compressor and save the quantized GraphModule
         model.eval()
         quantizer = Quantization('fx_dynamic_yaml.yaml')
@@ -941,6 +952,34 @@ class TestPytorchFXAdaptor(unittest.TestCase):
         self.assertEqual(model_fx.code, model_fx_recover.code)
         shutil.rmtree('./saved', ignore_errors=True)
 
+    def test_default_dynamic_quant(self):
+        def eval_func(model):
+            return 1
+
+        def q_func(model):
+            return model
+
+        # Model Definition
+        for fake_yaml in ['fx_qat_yaml.yaml', 'fx_ptq_yaml.yaml']:
+            model_origin = LSTMModel(
+                ntoken = 10,
+                ninp = 512,
+                nhid = 256,
+                nlayers = 2,
+            )
+            # run fx_quant in neural_compressor and save the quantized GraphModule
+            quantizer = Quantization(fake_yaml)
+            dataset = quantizer.dataset('dummy', (3, 10), label=True)
+            quantizer.eval_func = eval_func
+            if fake_yaml == 'fx_qat_yaml.yaml':
+                quantizer.q_func = q_func
+            else:
+                quantizer.calib_dataloader = common.DataLoader(dataset)
+            quantizer.model = common.Model(model_origin)
+            q_model = quantizer.fit()
+            self.assertTrue('quantize' in str(type(q_model._model.encoder)))
+            self.assertTrue('quantize' in str(type(q_model._model.rnn)))
+
     def test_fx_sub_module_quant(self):
         for fake_yaml in ['fx_qat_yaml.yaml', 'fx_ptq_yaml.yaml']:
             model_origin = DynamicControlModel()
@@ -980,5 +1019,53 @@ class TestPytorchFXAdaptor(unittest.TestCase):
             self.assertEqual(model_fx.sub.code, model_fx_recover.sub.code)
             shutil.rmtree('./saved', ignore_errors=True)
 
+    @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT111.value,
+      "Please use PyTroch 1.11 or higher version for mixed precision with pytorch_fx or pytorch backend")
+    def test_bf16_capability(self):
+        model_origin = DynamicControlModel()
+        os.environ['FORCE_BF16'] = '1'
+        q_capability = self.adaptor._get_quantizable_ops(model_origin)
+        del os.environ['FORCE_BF16']
+        self.assertEqual(q_capability['optypewise']['Conv2d']['weight']['dtype'], \
+            ['bf16', 'int8', 'fp32'])
+        self.assertEqual(q_capability['optypewise']['Conv2d']['activation']['dtype'], \
+            ['bf16', 'uint8', 'fp32'])
+        self.assertEqual(q_capability['optypewise']['Linear']['weight']['dtype'], \
+            ['bf16', 'int8', 'fp32'])
+        self.assertEqual(q_capability['optypewise']['Linear']['activation']['dtype'], \
+            ['bf16', 'uint8', 'fp32'])
+        self.assertEqual(q_capability['opwise'][('conv', 'Conv2d')]['weight']['dtype'], \
+                    ['bf16', 'int8', 'fp32'])
+        self.assertEqual(q_capability['opwise'][('conv', 'Conv2d')]['activation']['dtype'], \
+                    ['bf16', 'uint8', 'fp32'])
+    
+    @unittest.skipIf(PT_VERSION < PyTorchVersionMode.PT111.value,
+      "Please use PyTroch 1.11 or higher version for mixed precision with pytorch_fx or pytorch backend")
+    def test_mix_precision(self):
+        fake_yaml = 'fx_ptq_yaml.yaml'
+        model_origin = DynamicControlModel()
+        # run fx_quant in neural_compressor and save the quantized GraphModule
+        quantizer = Quantization(fake_yaml)
+        dataset = quantizer.dataset('dummy', (1, 3, 224, 224), label=True)
+        quantizer.eval_func = eval_func
+        quantizer.calib_dataloader = common.DataLoader(dataset)
+        quantizer.model = common.Model(model_origin,
+                              **{'prepare_custom_config_dict': \
+                                    {'non_traceable_module_name': ['a']},
+                               'convert_custom_config_dict': \
+                                    {'preserved_attributes': []}
+                              })
+        q_model = quantizer.fit()
+        tune_cfg = q_model.tune_cfg
+        tune_cfg['op'][('conv.module', 'Conv2d')].clear()
+        tune_cfg['op'][('conv.module', 'Conv2d')] = \
+            {'weight': {'dtype': 'bf16'}, 'activation': {'dtype': 'bf16'}}
+        tune_cfg["bf16_ops_list"].append(('conv.module', 'Conv2d'))
+        from neural_compressor.adaptor.torch_utils.bf16_convert import Convert
+        q_model._model = Convert(q_model._model, tune_cfg)
+
+        self.assertEqual(q_model._model.conv.module.module.weight.dtype, torch.bfloat16)
+        self.assertEqual(q_model._model.conv.module.module.bias.dtype, torch.bfloat16)
+
 if __name__ == "__main__":
     unittest.main()
