@@ -11,11 +11,11 @@ def helper(content):
 class TestPyConf(unittest.TestCase):
     def test_config(self):
         from neural_compressor import conf
-        from neural_compressor.conf.config import Quantization_Conf, Pruning_Conf, \
-            Graph_Optimization_Conf, Benchmark_Conf, Distillation_Conf
+        from neural_compressor.conf.config import QuantConf, PruningConf, \
+            GraphOptConf, BenchmarkConf, DistillationConf
         
         conf.tuning.accuracy_criterion.relative = 0.2
-        a = Quantization_Conf(conf)
+        a = QuantConf(conf)
         self.assertEqual(a.usr_cfg.tuning.accuracy_criterion.relative, 0.2)
 
         conf.quantization.op_wise = {
@@ -25,7 +25,7 @@ class TestPyConf(unittest.TestCase):
         conf.quantization.model_wise = {
             'activation': INT8_SYM_KL_PERTENSOR,
             'weight': INT8_SYM_MINMAX_PERTENSOR}
-        a = Quantization_Conf(conf)
+        a = QuantConf(conf)
         self.assertEqual(a.usr_cfg.quantization.model_wise.weight.scheme, ['sym'])
  
         conf.evaluation.performance.dataloader.dataset = {'dummy': {'shape': '224,224,3'}}
@@ -38,27 +38,27 @@ class TestPyConf(unittest.TestCase):
         conf.evaluation.performance.dataloader.batch_size = 6
         conf.evaluation.accuracy.metric = {'RMSE': {}}
         conf.tuning.strategy.name = 'mse'
-        a = Benchmark_Conf(conf)
+        a = BenchmarkConf(conf)
         self.assertEqual(a.usr_cfg.evaluation.performance.dataloader.batch_size, 6)
         self.assertEqual(a.usr_cfg.evaluation.performance.dataloader.dataset, {'dummy': {'shape': (224,224,3)}})
         self.assertEqual(a.usr_cfg.evaluation.accuracy.metric, {'RMSE': {}})
-        a = Quantization_Conf(conf)
+        a = QuantConf(conf)
         self.assertEqual(a.usr_cfg.tuning.strategy.name, 'mse')
  
         conf.evaluation.accuracy.metric = {'topk': 5}
         conf.graph_optimization.precisions = 'bf16'
         conf.pruning.train.criterion = {'CrossEntropyLoss': {}}
         conf.pruning.train.optimizer = {}
-        a = Pruning_Conf(conf)
+        a = PruningConf(conf)
         self.assertEqual(a.usr_cfg.pruning.train.criterion, {'CrossEntropyLoss': {'from_logits': False, 'reduction': 'mean'}})
 
         self.assertEqual(a.usr_cfg.evaluation.accuracy.metric, {'topk': 5})
         conf.graph_optimization.op_wise = BF16
-        a = Graph_Optimization_Conf(conf)
+        a = GraphOptConf(conf)
         self.assertEqual(a.usr_cfg.graph_optimization.op_wise, {'weight': {'dtype': ['bf16']}, 'activation': {'dtype': ['bf16']}})
 
         conf.distillation.train.iteration = 900
-        a = Distillation_Conf(conf)
+        a = DistillationConf(conf)
         self.assertEqual(a.usr_cfg.distillation.train.iteration, 900)
 
 class TestConf(unittest.TestCase):
@@ -439,7 +439,7 @@ class TestConf(unittest.TestCase):
               algorithm:  minmax
         '''
         helper(test)
-        config = conf.Quantization_Conf('fake_conf.yaml')
+        config = conf.QuantConf('fake_conf.yaml')
 
         framework_modelwise_capability = {
             'CONV2D': {
@@ -477,7 +477,7 @@ class TestConf(unittest.TestCase):
         helper(test)
 
         metrics = {'topk': 1, 'MSE': {}}
-        config = conf.Quantization_Conf('fake_conf.yaml')
+        config = conf.QuantConf('fake_conf.yaml')
         self.assertEqual(config.usr_cfg.evaluation.accuracy.multi_metrics, metrics)
 
         test = '''
@@ -506,7 +506,7 @@ class TestConf(unittest.TestCase):
               MSE: {}
         '''
         helper(test)
-        config = conf.Quantization_Conf('fake_conf.yaml')
+        config = conf.QuantConf('fake_conf.yaml')
         self.assertEqual(config.usr_cfg.evaluation.accuracy.multi_metrics.higher_is_better, [True, False])
 
     def test_modelwise_conf_merge2(self):
@@ -523,7 +523,7 @@ class TestConf(unittest.TestCase):
               dtype: ['uint8', 'fp32']
         '''
         helper(test)
-        config = conf.Quantization_Conf('fake_conf.yaml')
+        config = conf.QuantConf('fake_conf.yaml')
 
         framework_modelwise_capability = {
             'CONV2D': {
@@ -569,7 +569,7 @@ class TestConf(unittest.TestCase):
           
         '''
         helper(test)
-        config = conf.Quantization_Conf('fake_conf.yaml')
+        config = conf.QuantConf('fake_conf.yaml')
 
         framework_modelwise_capability = {
             'CONV2D': {
