@@ -6,6 +6,7 @@ import subprocess
 import unittest
 import re
 import tensorflow
+import torch
 
 def build_fake_ut():
     fake_ut = """
@@ -220,7 +221,8 @@ class TestMetrics(unittest.TestCase):
             with open('anno_0.yaml', 'w', encoding = "utf-8") as f:
                 f.write(fake_dict)
         while True:
-            if os.path.exists('anno_0.yaml'):
+            file_exists = hvd.allgather_object(os.path.exists('anno_0.yaml'))
+            if file_exists == [True, True]:
                 break
         mAP = metrics['mAP']('anno_0.yaml')
         mAP.hvd = hvd
@@ -401,7 +403,8 @@ class TestMetrics(unittest.TestCase):
             with open('anno_1.yaml', 'w', encoding = "utf-8") as f:
                 f.write(fake_dict)
         while True:
-            if os.path.exists('anno_1.yaml'):
+            file_exists = hvd.allgather_object(os.path.exists('anno_1.yaml'))
+            if file_exists == [True, True]:
                 break
         mAP = metrics['VOCmAP']('anno_1.yaml')
         mAP.hvd = hvd
@@ -565,7 +568,8 @@ class TestMetrics(unittest.TestCase):
             with open('anno_2.yaml', 'w', encoding = "utf-8") as f:
                 f.write(fake_dict)
         while True:
-            if os.path.exists('anno_2.yaml'):
+            file_exists = hvd.allgather_object(os.path.exists('anno_2.yaml'))
+            if file_exists == [True, True]:
                 break
         mAP = metrics['COCOmAP']('anno_2.yaml')
         mAP.hvd = hvd
@@ -961,7 +965,7 @@ class TestDistributed(unittest.TestCase):
         shutil.rmtree('./saved', ignore_errors = True)
         shutil.rmtree('runs', ignore_errors = True)
 
-    @unittest.skipIf(tensorflow.version.VERSION >= '2.8.0', "Only supports tf 2.7.0 or below")
+    @unittest.skipIf(tensorflow.version.VERSION >= '2.8.0' or torch.version.__version__ >= '1.10.0', "Only supports tf 2.7.0 or below and pytorch 1.9.0 or below")
     def test_distributed(self):
         distributed_cmd = 'horovodrun -np 2 python fake_ut.py'
         p = subprocess.Popen(distributed_cmd, preexec_fn = os.setsid, stdout = subprocess.PIPE,
